# Outputs of current speed and sea otter abundance models in Glacier Bay, Alaska
---

Contains:

A raster dataset of the root-mean-square current speed in Glacier Bay, Alaska produced by a tidal circulation model.

MCMC output from a Bayesian ecological diffusion model of sea otter spatio-temporal dynamics in Glacier Bay that can be used to generate a time series of sea otter abundance rasters.

## Description of the data and file structure

### Current speed

`current.zip` contains ArcGIS `.adf` raster files over the domain of Glacier Bay, Alaska. Defines a 100m x 100m grid. The value of each cell is the root-mean-square current speed derived from the tidal circulation model developed in Drew et al. The raster file is derived from a TIN (triangular irregular network) using the nearest neighbor algorithm.

The raster can be loaded into R using the `raster` package as follows:

`rms_field <- raster("current/w001001.adf")`

### Sea otter abundance

`otters.zip` contains three R object files (`.rds`) that enable the user to generate a time series of posterior mean sea otter abundance estimates across Glacier Bay over the years 1993 - 2018.

* `Boundaries.rds` defines the 400m x 400m raster over the domain of Glacier Bay.
* `lambda_covars.rds` contains a matrix with the number of rows equal to the number of cells in the above raster and 5 columns defining the covariate matrix (`X`) for the log-linear regression of sea otter diffusion rate defined in Lu et al. (2018).
* `lambda_mcmc.rds` contains a list of 12 elements. Each named element contains a matrix or vector of the MCMC chain of the corresponding parameter or derived quantity of the ecological diffusion model of Lu et al. (2018). Details of the MCMC algorithm that produced these posterior samples are provided in that manuscript (full citation below). 

The script `compute_lambda.r` in the code repository linked below uses these inputs to generate a raster brick containing the posterior mean estimate of sea otter abundance in each cell across the years 1993-2018 using the numerical solution to the ecological diffusion model, as detailed in Lu et al.

## Sharing/Access information

Current data was produced by:

Drew, G. S., Piatt, J. F., & Hill, D. F. (2013). Effects of currents and tides on fine-scale use of marine bird habitats in a Southeast Alaska hotspot. Marine Ecology Progress Series, 487, 275–286. https://doi.org/10.3354/meps10304

Sea otter data was produced by:

Lu, X., Williams, P. J., Hooten, M. B., Powell, J. A., Womble, J. N., & Bower, M. R. (2019). Nonlinear reaction–diffusion process models improve inference for population dynamics. Environmetrics, e2604, 1–17. https://doi.org/10.1002/env.2604

## Code/Software

Code for processing these data and aligning with intertidal and subtidal benthic invertebrate sampling sites is available at 
https://github.com/clint-leach/otter-clam